/*
 * Visible Human Project Java Program
 * by: Yuh-Jye Chang
 *
 * This Project contains 12 files:
 *
 * VisibleHuman.java  -- the Main Applet
 * ImageFrame.java    -- the Popup Image Frame
 * ImageSelector.java -- Image Object with a Selection Line
 * ImageCanvas.java   -- Image Process and Display Object
 * Scroller.java      -- Motif Look Scrollbar
 * Button3D.java      -- Motif Look 3D Button
 * Panel3D.java       -- Panel with 3D Outlook
 * Label3D.java       -- Label with 3D Outlook
 * Canvas3D.java      -- Canvas with 3D Outlook
 * Thumb.java         -- Thumb in Scrollbar
 * Setting.java       -- Global Setting Interface
 * Delay.java         -- Delay Interrupt Object
 *
 * The Class Hierarchy:
 *
 * Object --- Delay
 * Applet --- VisibleHuman
 * Frame  --- ImageFrame
 * Panel  --- Panel3D --- Scroller
 * Canvas --- Canvas3D -+- Label3D --- Button3D
 *                      |
 *                      +- ImageCanvas --- ImageSelector
 *                      |
 *                      +- Thumb
 *
 * The Component Hierarchy:
 *
 * VisibleHuman -+- board ----+- view[3] --+- logo (ImageCanvas)
 *               |  (Panel3D) |  (Panel)   |  
 *               |            |            +- npac (Button3D)
 *               |            |               
 *               |            +- view[0] --+- select[0] (ImageSelector)
 *               |            |  (Panel)   |  
 *               |            |            +- tagBtn[0] (Button3D)
 *               |            |               ("Axial")
 *               |            +- view[1] --+- select[1] (ImageSelector)
 *               |            |  (Panel)   |  
 *               |            |            +- tagBtn[1] (Button3D)
 *               |            |               ("Sagittal")
 *               |            +- view[2] --+- select[2] (ImageSelector)
 *               |               (Panel)   |  
 *               |                         +- tagBtn[2] (Button3D)
 *               |                            ("Coronal")
 *               +- panel ----+- resolutions -+- tagBtn[3] (Button3D)
 *                  (Panel)   |  (Panel3D)    |  ("Low")
 *                            |               +- tagBtn[4] (Button3D)
 *                            |               |  ("Medium")
 *                            |               +- tagBtn[5] (Button3D)
 *                            |                  ("High")
 *                            +- controls -+- adjust ---+- left (Button3D)
 *                               (Panel3D) |  (Panel3D) |  (triangle)
 *                                         |            +- right (Button3D)
 *                                         |               (triangle)
 *                                         +- slice (Label3D)
 *                                         |  (current slice number)
 *                                         +- load (Button3D)
 *
 * ImageFrame -+- picture ---+- canvas (ImageCanvas)
 *             |  (Panel)    |  (Center)
 *             |             +- hScroll (Scroller)
 *             |             |  (South, HORIZONTAL)
 *             |             +- vScroll (Scroller)
 *             |                (East, VERTICAL)
 *             +- controls --+- Quit (Button3D)
 *                (Panel3D)  |  ("Quit")
 *                           +- Download (Button3D)
 *                           |  ("Download")
 *                           +- Apply (Button3D)
 *                           |  ("Apply")
 *                           +- Org (Button3D)
 *                           |  ("1:1")
 *                           +- lbScale (Panel3D)
 *                           |  (current scale)
 *                           +- sbScale (Scrller)
 *                              (HORIZONTAL)
 *
 * Scroller ----+- up (Button3D)
 * (HORIZONTAL) |  (West, triangle)
 *              +- down (Button3D)
 *              |  (East, triangle)
 *              +- thumb (Thumb)
 *                 (Center)
 *
 * Scroller ----+- up (Button3D)
 * (VERTICAL)   |  (North, triangle)
 *              +- down (Button3D)
 *              |  (South, triangle)
 *              +- thumb (Thumb)
 *                 (Center)
 */

import java.applet.*;
import java.awt.*;
import java.net.*;
import java.io.*;
import java.util.StringTokenizer;

import webwisdom.tango.interfaces.*;
import webwisdom.tango.messages.*;
import webwisdom.tango.consts.*;

public class VisibleHuman extends AppletBase implements Runnable, Setting {
	boolean Master = true;
    static ImageFrame frameList = null;
    static URL codeBase, Fatch;
    static double scale = 1.0;
    static int maxp = 2;
    static int step = 50;
    static int wFrame = 580;
    static int hFrame = 420;
    static int offset = 24;
    static int no = 0;
    static int wrap;
    static int sliceOfs = 1001;
    static String LOAD = "Load";
    static String imgdir = "../0";
    static String tagName[] = {
      "Axial", "Sagittal", "Coronal", 
      "Low", "Medium", "High"};
    int current = 0, numberofFrames=0;
    int resolution = 0;
    boolean canStop = false;
    Panel panel, view[];
    Panel3D board, resolutions, controls, adjust;
    Label3D slice;
    Button3D tagBtn[], npac, load, left, right;
    ImageCanvas logo;
    ImageSelector select[];
    int sliceNo[] = { 860, 350, 600};

    public void init() {
		register();
        int i;
        int defaultRes = 1;
        int defaultView = 2;
        String arg;

        /* Get Current Screen Resolution */
        Dimension screenSize =
          Toolkit.getDefaultToolkit().getScreenSize();

        view = new Panel[4];
        tagBtn = new Button3D[6];
        select = new ImageSelector[3];

        /* Initialize Arguments pass from HTML */
        arg = getParameter("wframe");
        if (arg != null) wFrame = Integer.valueOf(arg).intValue();
        arg = getParameter("hframe");
        if (arg != null) hFrame = Integer.valueOf(arg).intValue();
        arg = getParameter("slicex");
        if (arg != null) sliceNo[0] = Integer.valueOf(arg).intValue();
        arg = getParameter("slicey");
        if (arg != null) sliceNo[1] = Integer.valueOf(arg).intValue();
        arg = getParameter("slicez");
        if (arg != null) sliceNo[2] = Integer.valueOf(arg).intValue();
        arg = getParameter("scale");
        if (arg != null) scale = Double.valueOf(arg).doubleValue();
        arg = getParameter("maxp");
        if (arg != null) maxp = Integer.valueOf(arg).intValue();
        arg = getParameter("step");
        if (arg != null) step = Integer.valueOf(arg).intValue();
        arg = getParameter("defaultRes");
        if (arg != null) defaultRes = Integer.valueOf(arg).intValue();
        arg = getParameter("defaultView");
        if (arg != null) defaultView = Integer.valueOf(arg).intValue();
        arg = getParameter("imgdir");
        if (arg != null) imgdir = arg;
      
        codeBase = getCodeBase();

        /* Set Main Applet to Border Layout */
        setLayout(new BorderLayout());

        /* Setup Components */
        logo = new ImageCanvas();
        logo.setPreferredSize(59, 59);
        logo.mode = 1;
        select[0] = new ImageSelector(this, 0, Scrollbar.HORIZONTAL, sliceNo[0], 0, 1728);
        select[0].setValue(sliceNo[0], false);
        select[0].setPreferredSize(100, 59);
        select[0].mode = 1;
        select[1] = new ImageSelector(this, 1, Scrollbar.HORIZONTAL, sliceNo[1], 0, 1000);
        select[1].setValue(sliceNo[1], false);
        select[1].setPreferredSize(59, 317);
        select[1].mode = 1;
        select[2] = new ImageSelector(this, 2, Scrollbar.VERTICAL, sliceNo[2], 0, 1878);
        select[2].setValue(sliceNo[2], false);
        select[2].setPreferredSize(100, 317);
        select[2].mode = 1;
        npac = new Button3D(this,"NPAC");
        view[3] = new Panel();
        view[3].setLayout(new BorderLayout());
        view[3].add("South", npac);
        view[3].add("Center", logo);
        board = new Panel3D();
        board.add(view[3]);
        for (i=0; i<3; i++) {
          view[i] = new Panel();
          view[i].setLayout(new BorderLayout());
          view[i].add("South", tagBtn[i] =
            new Button3D(this,Button3D.CHECKBTN, tagName[i]));
          view[i].add("Center", select[i]);
          tagBtn[i].setRatio(2);
          board.add(view[i]);
        }
        resolutions = new Panel3D();
        resolutions.add(tagBtn[3] =
          new Button3D(this,Button3D.CHECKBTN, tagName[3]));
        resolutions.add(tagBtn[4] =
          new Button3D(this,Button3D.CHECKBTN, tagName[4]));
        resolutions.add(tagBtn[5] =
          new Button3D(this,Button3D.CHECKBTN, tagName[5]));
        tagBtn[4].setRatio(3);
        adjust = new Panel3D();
        adjust.setLayout(new FlowLayout(FlowLayout.CENTER, d2, depth));
        adjust.add(left = new Button3D(this,Button3D.LEFT));
        adjust.add(right = new Button3D(this,Button3D.RIGHT));
        left.setBase(tagBtn[0].getBase()-8);
        right.setBase(tagBtn[0].getBase()-8);
        controls = new Panel3D();
        controls.add(adjust);
        controls.add(slice = new Label3D(String.valueOf(sliceNo[2])));
        controls.add(load = new Button3D(this,LOAD));
        load.setRatio(3);
        slice.setActive(false);
        panel = new Panel();
        panel.setLayout(new GridLayout(2, 1));
        panel.add(controls);
        panel.add(resolutions);
		//panel.add(new Load3DPanel(this));

        add("Center", board);
        add("South", panel);
        setCurrent(defaultView);
        setResolution(defaultRes+3);
        sliceNo[0] = sliceNo[1] = sliceNo[2] = -1;

        /* Caculate offsets for Pupup ImageFrame */
        int wrapx = (screenSize.width-offset*4-wFrame)/offset;
        wrap = (screenSize.height-offset*4-hFrame)/offset;
        if ( wrap > wrapx ) wrap = wrapx;
        if ( wrap < 1 ) wrap = 1;
        /* Caculate the Width and Height of Applet
        int wApp=59+100+4*3+depth*2;
        int hApp=59+317+4*3+controls.preferredSize().height*2+depth*2+44;
        System.out.println("W"+wApp+" H"+hApp);
        */
    }
    public void start() {
        /* Setup Image into Image Object */
        logo.updateImage(getImage(codeBase, "../logo.gif"));
        updatePreview();
    }
    private void updatePreview() {
        /* Update Image only when slice number is changed */
        if ( sliceNo[0] != select[0].getValue()/18 ) {
          sliceNo[0] = select[0].getValue()/18;
          select[1].updateImage(getImage(codeBase, imgdir+
            "JPEGX-18/a_vmX"+(sliceNo[0]+sliceOfs)+"-18.jpg"));
        }
        if ( sliceNo[1] != select[1].getValue()/18 ) {
          sliceNo[1] = select[1].getValue()/18;
          select[2].updateImage(getImage(codeBase, imgdir+
            "JPEGY-18/a_vmY"+(sliceNo[1]+sliceOfs)+"-18.jpg"));
        }
        if ( sliceNo[2] != select[2].getValue()/6 ) {
          sliceNo[2] = select[2].getValue()/6;
          select[0].updateImage(getImage(codeBase, imgdir+
            "JPEG-18/a_vm"+(sliceNo[2]+sliceOfs)+"-18.jpg"));
        }
    }
    public void stop() {
        /* Destroy all the Popup ImageFrame Windows */
        while ( frameList != null )
          frameList.dispose();
    }
    private void setCurrent(int _current) {
        /* Select the current Viewport */
        if ( current == _current ) return;
        int i, j, k;
        current = _current;
        k = (current+1)%3;
        showStatus("Select "+tagName[k]+" View");
        for (i=0; i<3; i++) {
          tagBtn[i].setActive(i!=k);
          select[i].setMode((i==k) ? -1 : 1);
          select[i].setColor((i==current) ? Color.cyan : Color.red);
        }
        left.setType((current == 2)? Button3D.UP : Button3D.LEFT);
        right.setType((current == 2)? Button3D.DOWN : Button3D.RIGHT);
        slice.setText(String.valueOf(select[current].getValue()));
        
    }
    private void setResolution(int _resolution) {
        /* Select the current Resolution */
        if ( resolution == _resolution ) return;
        resolution = _resolution;
        showStatus("Set resolution to "+tagName[resolution]);
        for (int i=3; i<6; i++)
          tagBtn[i].setActive(i!=resolution);
    }

    public void run() {
        /* Fatch the URL and Show Document 
        showStatus(Fatch.toString());
        getAppletContext().showDocument(Fatch);
        */
    }

    public void showHTML(String newURL) {
        /*byte[] buffer=new byte[newURL.length()];
        newURL.getBytes(0, newURL.length(),buffer,0);
        byte [] d=CAppRequestEventMessage.prepareData("HTML Browser",buffer);
        CAppRequestEventMessage cap=new CAppRequestEventMessage(d);
        send(cap);*/
        try {
          Fatch = new URL(codeBase, newURL);
          new Delay(100, -1, this);
        } catch (MalformedURLException e){};
        getAppletContext().showDocument(Fatch,"_black");
       System.out.println("buradayim");
    }

    public boolean keyDown(Event ev, int key) {
        if ( key < 0 ) (new Thread(this)).start();
        return true;
    }

    public boolean doAction(String mes) {
		int id;
		if(mes == null) return false;
		StringTokenizer parser = new StringTokenizer(mes);
		if(parser.countTokens()<1) return false;
        String s = parser.nextToken();
        if (s.equals("LOAD")) {
          //if ( canStop ) {
           // canStop = false;
            //load.setText(LOAD);
            //if ( frameList != null )
             // frameList.dispose();
            //return true;
          //}
          int x = offset*((no%wrap)+2);
          int slice = select[current].getValue();
          int yScale = 1;
          URL dataBase = codeBase;
          double kScale = 1.0;
          String path = imgdir+"JPEG";
          updatePreview();
          switch ( resolution ) {
            case 3 : path += "-L"; break;
            case 4 : path += "-M"; break;
          }
          switch ( current ) {
            case 0 : // Sagittal Image
              path += "X/a_vmX"+(slice+sliceOfs);
              if ( resolution == 5 ) {
                yScale = 3;
                kScale = scale;
              }
              break;
            case 1 : // Coronal Image
              path += "Y/a_vmY"+(slice+sliceOfs);
              if ( resolution == 5 ) {
                yScale = 3;
                kScale = scale;
              }
              break;
            default : // Axial Image
              path += "/a_vm"+(slice+sliceOfs);
              break;
          }
          switch ( resolution ) {
            case 3 : path += "-L"; break;
            case 4 : path += "-M"; break;
          }
          path += ".jpg";
          //canStop = true;
          new ImageFrame(this,
            "2D Viewer No."+(++no)+" "+
            tagBtn[(current+1)%3].getText()+" "+
            tagBtn[resolution].getText()+" "+
            "Slice#"+slice, path,
            getImage(dataBase, path), x, x,
            wFrame, hFrame, kScale, 1, yScale, maxp, step,numberofFrames);
		    numberofFrames++;
          //if ( canStop ) load.setText("Stop");
          //else canStop = false;
          return true;
        } 
		else if (s.equals("LEFT")) {
           if(parser.countTokens()<1) return false;
		   id = Integer.parseInt(parser.nextToken());
           //System.out.println("LEFT"+id);
           if ( id != Event.MOUSE_UP ) {
            int v = select[current].getValue()-1;
            if ( select[current].setValue(v, true) )
              slice.setText(String.valueOf(v));
          } else updatePreview();
          return true;
        } else if (s.equals("RIGHT")) {
		   if(parser.countTokens()<1) return false;
           id = Integer.parseInt(parser.nextToken());
            //System.out.println("RIGHT"+id);
           if ( id != Event.MOUSE_UP ) {
            int v = select[current].getValue()+1;
            if ( select[current].setValue(v, true) )
              slice.setText(String.valueOf(v));
          } else updatePreview();
          return true;
        } else if (s.equals("SELECT0")) {
		    if(parser.countTokens()<1) return false;
            id = Integer.parseInt(parser.nextToken());
            //System.out.println("SELECT0"+id);	
          switch ( id ) {
            case Event.MOUSE_DOWN : setCurrent(0); break;
            case Event.MOUSE_UP : updatePreview(); break;
            case Event.MOUSE_DRAG : break;
            default: setCurrent(2);
          }
          slice.setText(String.valueOf(select[current].getValue()));
          return true;
        } else if (s.equals("SELECT1")) {
		  	if(parser.countTokens()<1) return false;
            id = Integer.parseInt(parser.nextToken());  
            //System.out.println("SELECT1"+id); 
          switch ( id ) {
            case Event.MOUSE_DOWN : setCurrent(1); break;
            case Event.MOUSE_UP : updatePreview(); break;
            case Event.MOUSE_DRAG : break;
            default: setCurrent(0);
          }
          slice.setText(String.valueOf(select[current].getValue()));
          return true;
        } else if (s.equals("SELECT2")) {
		    if(parser.countTokens()<1) return false;
            id = Integer.parseInt(parser.nextToken());  
            //System.out.println("SELECT2"+id); 
          switch ( id ) {
            case Event.MOUSE_DOWN : setCurrent(2); break;
            case Event.MOUSE_UP : updatePreview(); break;
            case Event.MOUSE_DRAG : break;
            default: setCurrent(1);
          }
          slice.setText(String.valueOf(select[current].getValue()));
          return true;
        } else if (s.equals("TAGBUTTON0")) {
          setCurrent(2);
          return true;
        } else if (s.equals("TAGBUTTON1")) {
          setCurrent(0);
          return true;
        } else if (s.equals("TAGBUTTON2")) {
          setCurrent(1);
          return true;
        } else if (s.equals("TAGBUTTON3")) {
          setResolution(3);
          return true;
        } else if (s.equals("TAGBUTTON4")) {
          setResolution(4);
          return true;
        } else if (s.equals("TAGBUTTON5")) {
          setResolution(5);
          return true;
        } else if (s.equals("SHOWHTML")) {
            showHTML("http://www.npac.syr.edu");
          return true;
        } else if (s.equals("SHOWSTRING")) {
		  if(parser.countTokens()<1) return false;	
          showHTML(parser.nextToken());
          return true;
        }  else if (s.equals("LAST")) {
          //if ( canStop ) {
           // canStop = false;
            //if ( load.getText() != LOAD )
             // load.setText(LOAD);
          //}
          return true;
        } /*else if (s.equals("Load3DChooser")){
		  if(parser.countTokens()<1) return false;
          sendDatatoVIEWER(false,parser.nextToken());
        }*/
	
        return false;
    }

	public void receive (AppEventMessage em) {
        //System.out.println("I am in receive");
		try {
			if (em.getType() == Const.CONTROL) 
            {   //System.out.println("em.getType() == Const.CONTROL"); 
				CAppAnswerEventMessage msg = (CAppAnswerEventMessage) em;
				if(msg.getAnswerType() == CAConsts.ISMASTER)
				{ Master = msg.isMaster();
				  if(Master) System.out.println("I am master ");
					else System.out.println("I am slave");
				}
 				return;
			}
        	String mes = new String(em.getData(),0,0,em.getLen());
			//System.out.println("Received  -->  "+mes);
            StringTokenizer parser = new StringTokenizer(mes);
            if(parser.countTokens()<1) return;
            String r = parser.nextToken();
        	if(r.equals("VH")) doAction(mes.substring(3)); 
			 else if(r.equals("IS")) 
              { if(parser.countTokens()<1) return;
                r = parser.nextToken();
                if(parser.countTokens()<1) return;
                int id  = Integer.parseInt(parser.nextToken());
                if(r.equals("MOUSEDOWN")) select[id].domouseDown(mes.substring(15));
                else if(r.equals("MOUSEUP")) select[id].domouseUp(mes.substring(13));
                else if(r.equals("DELAYDRAG")) select[id].dodelayDrag(mes.substring(15));
              }
			  else if(r.equals("IF"))
              { if(parser.countTokens()<1) return; 
                if((parser.nextToken()).equals("QUIT")) 
                {  if(parser.countTokens()<1) return;
                   int id = Integer.parseInt(parser.nextToken());
                   boolean cont = true;
                   ImageFrame next = frameList;
                   while(next!=null && next.getID()!=id)
        		   next = next.next; 
                   if(next!=null) next.dispose();
                }
              }
		} catch (Exception e) { e.printStackTrace(); }
	}

	public void sendMessage(String str)
    { byte [] t = new byte[str.length()];
      str.getBytes(0, str.length(), t, 0);
      AppEventMessage em = new AppEventMessage(Const.DATA, t);
      send(em);
    }

    public void sendDatatoVIEWER(boolean control, String newURL) {
        System.out.println("sendDatatoBrowser "+newURL);
		byte[] buffer=new byte[newURL.length()];	
        newURL.getBytes(0, newURL.length(),buffer,0);
		byte [] d=CAppRequestEventMessage.prepareData("GIS",buffer);
		CAppRequestEventMessage cap=new CAppRequestEventMessage(d);
        send(cap);
        if(control) {
        String ss = "VH "+"Load3DChooser "+newURL;
        byte [] t = new byte[ss.length()];
        ss.getBytes(0, ss.length(), t, 0);
        AppEventMessage  em = new AppEventMessage(Const.DATA, t);
        send(em); }
    }

    public void sendDatatoBrowser(String newURL) {
        showHTML(newURL);
        String ss = "VH "+"SHOWHTML "+newURL;
        byte [] t = new byte[ss.length()];
        ss.getBytes(0, ss.length(), t, 0);
        AppEventMessage  em = new AppEventMessage(Const.DATA, t);
        send(em);
    }

    public boolean action(Event ev, Object arg) {
	 //System.out.println("VisibleHuman.java - action");
     if(!Master) return true;
	 String s = null;
        if ( arg == load ) {
			s = "LOAD";
        } else if (arg == left) {
			s = "LEFT "+ev.id;
        } else if (arg == right) {
			s = "RIGHT "+ev.id;
        } else if (arg == select[0]) {
			s = "SELECT0 "+ev.id;
        } else if (arg == select[1]) {
			s = "SELECT1 "+ev.id;
        } else if (arg == select[2]) {
			s = "SELECT2 "+ev.id;
        } else if (arg == tagBtn[0]) {
			s = "TAGBUTTON0";
        } else if (arg == tagBtn[1]) {
			s = "TAGBUTTON1";
        } else if (arg == tagBtn[2]) {
			s = "TAGBUTTON2";
        } else if (arg == tagBtn[3]) {
			s = "TAGBUTTON3";
        } else if (arg == tagBtn[4]) {
			s = "TAGBUTTON4";
        } else if (arg == tagBtn[5]) {
			s = "TAGBUTTON5";
        } else if ((arg == logo) || (arg == npac)) {
          if ( (ev.id == Event.MOUSE_DOWN) || (arg == npac) )
			s = "SHOWHTML";
        } else if (arg instanceof String) {
			s = "SHOWSTRING "+ (String)arg;
          
        }  else if ((frameList != null) && (arg == frameList)) {
			s = "LAST";
        }
		if(doAction(s)) 
		{ String ss = "VH "+s;
          //System.out.println("Sending   -->  "+ss);
		  byte [] t = new byte[ss.length()];
		  ss.getBytes(0, ss.length(), t, 0);
		  AppEventMessage em = new AppEventMessage(Const.DATA, t);
		  send(em);
		  return true;
		}
		return false;
    }
}

class Load3DPanel extends Panel3D
{ VisibleHuman root;
  Choice Load3DChooser;

  String ivURLs[] ={ "http://www.npac.syr.edu/projects/3Dvisiblehuman/VRML/UPSHOULDER.iv",
                   "http://www.npac.syr.edu/projects/3Dvisiblehuman/VRML/HEAD.iv",
                   "http://www.npac.syr.edu/projects/3Dvisiblehuman/VRML/BRAIN.iv",
                   "http://www.npac.syr.edu/projects/3Dvisiblehuman/VRML/HEART.iv",
                   "http://www.npac.syr.edu/projects/3Dvisiblehuman/VRML/SKELETON.iv", 
                   "http://www.npac.syr.edu/projects/3Dvisiblehuman/VRML/STOMACH.iv",
                   "http://www.npac.syr.edu/projects/3Dvisiblehuman/VRML/LUNG.iv",
                   "http://www.npac.syr.edu/projects/3Dvisiblehuman/VRML/INTESTINES.iv",
                   "http://www.npac.syr.edu/projects/3Dvisiblehuman/VRML/LIVER.iv",
                   "http://www.npac.syr.edu/projects/3Dvisiblehuman/VRML/FOOT.iv"
                   };
  String URLs[] ={ "http://www.npac.syr.edu/projects/3Dvisiblehuman/VRML/UPSHOULDER.html",
                   "http://www.npac.syr.edu/projects/3Dvisiblehuman/VRML/HEAD.html",
                   "http://www.npac.syr.edu/projects/3Dvisiblehuman/VRML/BRAIN.html",
                   "http://www.npac.syr.edu/projects/3Dvisiblehuman/VRML/HEART.html",
                   "http://www.npac.syr.edu/projects/3Dvisiblehuman/VRML/SKELETON.html", 
                   "http://www.npac.syr.edu/projects/3Dvisiblehuman/VRML/STOMACH.html",
                   "http://www.npac.syr.edu/projects/3Dvisiblehuman/VRML/LUNG.html",
                   "http://www.npac.syr.edu/projects/3Dvisiblehuman/VRML/INTESTINES.html",
                   "http://www.npac.syr.edu/projects/3Dvisiblehuman/VRML/LIVER.html",
                   "http://www.npac.syr.edu/projects/3Dvisiblehuman/VRML/FOOT.html"
                   };

	Load3DPanel(VisibleHuman _root)
    { root= _root; 
      Load3DChooser = new Choice();
      Load3DChooser.addItem("");
      Load3DChooser.addItem("Head & Shoulder");
      Load3DChooser.addItem("Head");
      Load3DChooser.addItem("Brain");
      Load3DChooser.addItem("Heart");
      Load3DChooser.addItem("Skeleton");
      Load3DChooser.addItem("Stomach");
      Load3DChooser.addItem("Lung");
      Load3DChooser.addItem("Intestines");
      Load3DChooser.addItem("Liver");
      Load3DChooser.addItem("Foot");
      Load3DChooser.addItem("");
      add(new Label3D("3D LOAD"));
      add(Load3DChooser);
      if(!root.Master) Load3DChooser.disable();
    }

    public boolean action(Event e, Object arg)
    { if(!root.Master) return true; 
      if(e.target == Load3DChooser)
      { int indx = Load3DChooser.getSelectedIndex();
        if(indx>0&&indx<11) {
             //root.sendDatatoVIEWER(true,ivURLs[indx-1]);
             //root.sendDatatoBrowser(URLs[indx-1]);
             root.showHTML(URLs[indx-1]);
        }
        else
	{ 
//root.sendDatatoBrowser("http://www.npac.syr.edu/projects/3Dvisiblehuman");
	}
      }
      return true;
    }
}
