/*************************************************************************

	File Name	: NonUniformFlow.java

	Function	: Get non uniform flow input

	Input		:

		CFD smain	  : CFD main class

**************************************************************************/

import java.awt.*;
import java.util.*;
import java.lang.*;
import java.awt.event.*;
import java.applet.Applet;

public class NonUniformFlow extends Panel {

	CFD smain;

	// items
	Choice SourceType;
	TextField XPos;
	TextField YPos;
	TextField Strength;

	List ItemList;
	Button addButton;
	Button deleteButton;
	Button clearButton;

 	// message variables
	String messageSpace	= " ";

	String messageToBeSent	= null;
	String messageHead	= "1";
	String messageTotalData	= null;
	String messageAdd	= "11";
	String messageDelete	= "12";
	String messageClear	= "13";
	String messageHistory	= "14";
	String messageBody	= null;
	String messageEnd	= "kimd";

       /*****************************************************************
	*
	*	method	 : maketitle()
	*	Input    : String name,
	*		   GridBagLayout gridbag,
	*		   GridBagConstraints c
	*	Output   : none
	*	Function : make a title of this class
	*
	*****************************************************************/
	protected void maketitle(
				String name,
				GridBagLayout gridbag,
				GridBagConstraints c) {
		c.anchor = GridBagConstraints.SOUTH;

		Label label = new Label(name);

		// Font for Panel Title
		label.setFont(new Font("Dialog", Font.BOLD, 10));
		gridbag.setConstraints(label, c);
		add(label);
	}

       /*****************************************************************
	*
	*	method	 : makelabel()
	*	Input    : String name,
	*		   GridBagLayout gridbag,
	*		   GridBagConstraints c
	*	Output   : none
	*	Function : make a label
	*
	*****************************************************************/
	protected void makelabel(
				String name,
				GridBagLayout gridbag,
				GridBagConstraints c) {
		c.anchor = GridBagConstraints.SOUTH;

		Label label = new Label(name);

		// Font for label
		label.setFont(new Font("Dialog", Font.PLAIN, 8));

		gridbag.setConstraints(label, c);
		add(label);
	}

       /*****************************************************************
	*
	*	method	 : NonUniformFlow()
	*
	*	Function : constructor of this class
	*
	*****************************************************************/
	NonUniformFlow(CFD smain) {

		this.smain = smain;

		GridBagLayout gridbag = new GridBagLayout();
		GridBagConstraints c = new GridBagConstraints();
		setLayout(gridbag);

		// Font for Panel Main
		setFont(new Font("Dialog", Font.PLAIN, 10));

		c.fill = GridBagConstraints.BOTH;

		// 1st line
		c.gridwidth = 3;                //reset to the default
		c.weightx = 1.0;
		c.weighty = 0;
		c.insets = new Insets(0, 0, 0, 0);

		makelabel("Type", gridbag, c);
		makelabel("X Pos", gridbag, c);
		c.gridwidth = GridBagConstraints.RELATIVE;
		makelabel("Y Pos", gridbag, c);
		c.gridwidth = GridBagConstraints.REMAINDER; //end row
		makelabel("Strength", gridbag, c);

		// 2nd line
		c.gridwidth = 3;                //reset to the default
		c.weightx = 1.0;
		c.weighty = 0;
		c.insets = new Insets(0, 0, 0, 0);
		c.anchor = GridBagConstraints.SOUTH;

		SourceType = new Choice();
		SourceType.addItem("Source");
		SourceType.addItem("Sink");
		SourceType.addItem("Vortex");
		SourceType.addItem("Doublet");
		add(SourceType);
		gridbag.setConstraints(SourceType, c);

		XPos = new TextField("0", 7);
		gridbag.setConstraints(XPos, c);
		add(XPos);

		c.gridwidth = GridBagConstraints.RELATIVE;
		YPos = new TextField("0", 7);
		gridbag.setConstraints(YPos, c);
		add(YPos);

		c.gridwidth = GridBagConstraints.REMAINDER; //end row
		Strength = new TextField("1", 7);
		gridbag.setConstraints(Strength, c);
		add(Strength);

		// 3rd line
		c.weightx = 1;
		c.weighty = 1;
		c.gridwidth = 9;
		c.gridheight = 3;

		// add the history 
		ItemList = new List();
		ItemList.setFont(new Font("Dialog", Font.PLAIN, 10));
		add(ItemList);
		gridbag.setConstraints(ItemList, c);

		// add, delete, clear buttons
		c.gridwidth = GridBagConstraints.REMAINDER;
		c.gridheight = 1;
		c.weighty = 1;
		c.ipadx = 0;

		addButton = new Button("Add");
		gridbag.setConstraints(addButton, c);
		add(addButton);

		deleteButton = new Button("Delete");
		gridbag.setConstraints(deleteButton, c);
		add(deleteButton);

		clearButton = new Button("Clear");
		gridbag.setConstraints(clearButton, c);
		add(clearButton);

	}

       /*****************************************************************
	*
	*	method	 : handleEvent()
	*	Input    : Event event
	*	Output   : boolean
	*
	*****************************************************************/
	public boolean handleEvent(Event event) {

		if (event.target == addButton && event.id == Event.ACTION_EVENT) {
			addButton_Clicked(event);
		}

		else if (event.target == deleteButton && event.id == Event.ACTION_EVENT) {
			deleteButton_Clicked(event);
		}

		else if (event.target == clearButton && event.id == Event.ACTION_EVENT) {
			clearButton_Clicked(event);
		}

		else if (event.target == ItemList && event.id == Event.LIST_SELECT) {
			ItemList_Clicked(event);
		}

		else if (event.target == SourceType && event.id == Event.ACTION_EVENT) {

		}

		else if (event.target == XPos && event.id == Event.ACTION_EVENT) {

		}

		else if (event.target == YPos && event.id == Event.ACTION_EVENT) {

		}

		else if (event.target == Strength && event.id == Event.ACTION_EVENT) {

		}

		return false;
	}

       /*****************************************************************
	*
	*	method	 : addButton_Clicked()
	*	Input    : Event event
	*	Output   : none
	*	Function : Action when the ADD button is clicked
	*
	*****************************************************************/
	void addButton_Clicked(Event event) {

		int	sourceType;
		double	Xcoordinate;
		double	Ycoordinate;
		double	strength;

		sourceType = SourceType.getSelectedIndex();

		try {
			Xcoordinate = Double.valueOf(XPos.getText()).doubleValue();
			Ycoordinate = Double.valueOf(YPos.getText()).doubleValue();
			strength = Double.valueOf(Strength.getText()).doubleValue();
		}
		catch(Exception e) {
			return;
		}

		messageTotalData = Integer.toString(smain.numOfSource);

		messageToBeSent = messageHead + messageSpace
				+ messageTotalData + messageSpace
				+ messageAdd + messageSpace
				+ Integer.toString(sourceType) + messageSpace
				+ Double.toString(Xcoordinate) + messageSpace
				+ Double.toString(Ycoordinate) + messageSpace
				+ Double.toString(strength) + messageSpace
				+ messageEnd;

		smain.send_message(messageToBeSent);
	}

       /*****************************************************************
	*
	*	method	 : deleteButton_Clicked()
	*	Input    : Event event
	*	Output   : none
	*	Function : Action when the DELETE button is clicked
	*
	*****************************************************************/
	void deleteButton_Clicked(Event event) {

		int	itemIndex;
		int	i;

		itemIndex = ItemList.getSelectedIndex();

		if (smain.numOfSource < 1 || itemIndex < 0) {
			return;
		}

		messageTotalData = Integer.toString(smain.numOfSource);

		messageToBeSent = messageHead + messageSpace
				+ messageTotalData + messageSpace
				+ messageDelete + messageSpace
				+ Integer.toString(itemIndex) + messageSpace
				+ messageEnd;

		smain.send_message(messageToBeSent);
	}

       /*****************************************************************
	*
	*	method	 : clearButton_Clicked()
	*	Input    : Event event
	*	Output   : none
	*	Function : Action when the CLEAR button is clicked
	*
	*****************************************************************/
	void clearButton_Clicked(Event event) {

		if (smain.numOfSource <= 0) {
			return;
		}

		messageTotalData = Integer.toString(smain.numOfSource);

		messageToBeSent = messageHead + messageSpace
				+ messageTotalData + messageSpace
				+ messageClear + messageSpace
				+ messageEnd;

		smain.send_message(messageToBeSent);
	}

       /*****************************************************************
	*
	*	method	 : ItemList_Clicked()
	*	Input    : Event event
	*	Output   : none
	*	Function : Action when one of the data in the List is clicked
	*
	*****************************************************************/
	void ItemList_Clicked(Event event) {

		int	itemIndex;

		if (smain.numOfSource <= 0) {
			return;
		}

		itemIndex  = ItemList.getSelectedIndex();

		messageTotalData = Integer.toString(smain.numOfSource);

		messageToBeSent = messageHead + messageSpace
				+ messageTotalData + messageSpace
				+ messageHistory + messageSpace
				+ Integer.toString(itemIndex) + messageSpace
				+ messageEnd;

		smain.send_message(messageToBeSent);
	}
}
