/*************************************************************************

	File Name	: UniformFlow.java

	Function	: Get uniform flow input

	Input		:

		CFD smain	  : CFD main class

**************************************************************************/

import java.awt.*;
import java.util.*;
import java.lang.*;
import java.awt.event.*;
import java.applet.Applet;

public class UniformFlow extends Panel {

	CFD smain;

	// items
	Checkbox enableButton;
	Checkbox disableButton;

	Button applyButton;
	TextField Direction;
	TextField Velocity;

	// message variables
	String messageSpace	= " ";

	String messageToBeSent	= null;
	String messageHead	= "2";
	String messageTotalData	= null;
	String messageApply	= "21";
	String messageDisable	= "22";
	String messageBody	= null;
	String messageEnd	= "kimd";

       /*****************************************************************
	*
	*	method	 : maketitle()
	*	Input    : String name,
	*		   GridBagLayout gridbag,
	*		   GridBagConstraints c
	*	Output   : none
	*	Function : make a title of this class
	*
	*****************************************************************/
	protected void maketitle(
				String name,
				GridBagLayout gridbag,
				GridBagConstraints c) {
		Label label = new Label(name);
		// Font for Panel Title
		label.setFont(new Font("Dialog", Font.BOLD, 10));
		gridbag.setConstraints(label, c);
		add(label);
	}

       /*****************************************************************
	*
	*	method	 : makelabel()
	*	Input    : String name,
	*		   GridBagLayout gridbag,
	*		   GridBagConstraints c
	*	Output   : none
	*	Function : make a label
	*
	*****************************************************************/
	protected void makelabel(
				String name,
				GridBagLayout gridbag,
				GridBagConstraints c) {
		Label label = new Label(name);
		// Font for label
		label.setFont(new Font("Dialog", Font.PLAIN, 8));
		gridbag.setConstraints(label, c);
		add(label);
	}

       /*****************************************************************
	*
	*	method	 : UniformFlow()
	*
	*	Function : constructor of this class
	*
	*****************************************************************/
	UniformFlow(CFD smain) {

		this.smain = smain;

		GridBagLayout gridbag = new GridBagLayout();
		GridBagConstraints c = new GridBagConstraints();
		setLayout(gridbag);

		// Font for Panel Main
		setFont(new Font("Dialog", Font.PLAIN, 10));

		c.fill = GridBagConstraints.BOTH;

		// 1st line
		c.gridwidth = 1;                //reset to the default
		c.weightx = 1.0;

		makelabel("", gridbag, c);
		makelabel("", gridbag, c);
		makelabel("Direction", gridbag, c);
		c.gridwidth = GridBagConstraints.RELATIVE;
		makelabel("Velocity", gridbag, c);
		c.gridwidth = GridBagConstraints.REMAINDER; //end row
		makelabel("", gridbag, c);

		// 2nd line
		c.gridwidth = 1;                //reset to the default
		c.weightx = 1.0;

		CheckboxGroup uniform_switch = new CheckboxGroup();
		enableButton  = new Checkbox("enable",  uniform_switch, false);
		disableButton = new Checkbox("disable", uniform_switch, true);

		gridbag.setConstraints(enableButton, c);
		add(enableButton);

		gridbag.setConstraints(disableButton, c);
		add(disableButton);

		c.gridwidth = 1;                //reset to the default
		Direction = new TextField("0", 5);
		Direction.setEnabled(false);
		gridbag.setConstraints(Direction, c);
		add(Direction);

		c.gridwidth = GridBagConstraints.RELATIVE;
		Velocity = new TextField("1", 5);
		Velocity.setEnabled(false);
		gridbag.setConstraints(Velocity, c);
		add(Velocity);

		c.gridwidth = GridBagConstraints.REMAINDER; //end row
		applyButton = new Button("apply");
		applyButton.setEnabled(false);
		gridbag.setConstraints(applyButton, c);
		add(applyButton);

	}

       /*****************************************************************
	*
	*	method	 : handleEvent()
	*	Input    : Event event
	*	Output   : boolean
	*
	*****************************************************************/
	public boolean handleEvent(Event event) {

		if (event.target == disableButton && event.id == Event.ACTION_EVENT) {
			disableButton_Clicked(event);
		}

		else if (event.target == enableButton && event.id == Event.ACTION_EVENT) {
			enableButton_Clicked(event);
		}

		else if (event.target == Direction && event.id == Event.ACTION_EVENT) {
		}

		if (event.target == Velocity && event.id == Event.ACTION_EVENT) {
		}

		else if (event.target == applyButton && event.id == Event.ACTION_EVENT) {
			applyButton_Clicked(event);
		}

		return false;
	}

       /*****************************************************************
	*
	*	method	 : enableButton_Clicked()
	*	Input    : Event event
	*	Output   : none
	*	Function : Action when the ENABLE button is clicked
	*
	*****************************************************************/
	void enableButton_Clicked(Event event) {

		applyButton.setEnabled(true);
		Direction.setEnabled(true);
		Velocity.setEnabled(true);
	}

       /*****************************************************************
	*
	*	method	 : disableButton_Clicked()
	*	Input    : Event event
	*	Output   : none
	*	Function : Action when the DISABLE button is clicked
	*
	*****************************************************************/
	void disableButton_Clicked(Event event) {

		applyButton.setEnabled(false);
		Direction.setEnabled(false);
		Velocity.setEnabled(false);

		messageTotalData = Integer.toString(smain.numOfSource);

		messageToBeSent = messageHead + messageSpace
				+ messageTotalData + messageSpace
				+ messageDisable + messageSpace
				+ messageEnd;

		smain.send_message(messageToBeSent);
	}

       /*****************************************************************
	*
	*	method	 : applyButton_Clicked()
	*	Input    : Event event
	*	Output   : none
	*	Function : Action when the APPLY button is clicked
	*
	*****************************************************************/
	void applyButton_Clicked(Event event) {

		double	direction;
		double	velocity;

		try {
			direction = Double.valueOf(Direction.getText()).doubleValue();
			velocity  = Double.valueOf(Velocity.getText()).doubleValue();
		}
		catch(Exception e) {
			return;
		}

		messageTotalData = Integer.toString(smain.numOfSource);

		messageToBeSent = messageHead + messageSpace
				+ messageTotalData + messageSpace
				+ messageApply + messageSpace
				+ Double.toString(direction) + messageSpace
				+ Double.toString(velocity)  + messageSpace
				+ messageEnd;

		smain.send_message(messageToBeSent);
	}

}